```
Usage: vcd vapp network services firewall enable-firewall [OPTIONS] <vapp-
                                                          name> <network-name>

Options:
  --enable / --disable
  -h, --help            Show this message and exit.

```
